@@ -1,9 +1,37 @@
 package Acme::Time::Baby;
 
 #
-# $Id: Baby.pm,v 1.7 2002/05/15 11:37:39 abigail Exp abigail $
+# $Id: Baby.pm,v 2.100 2003/02/13 13:01:34 abigail Exp $
 #
 # $Log: Baby.pm,v $
+# Revision 2.100  2003/02/13 13:01:34  abigail
+# - Upped version to 2.100, to make really sure CPAN updates older
+#   versions of the module.
+# - Added Spanish. (Nick Tonkin)
+# - 17295 tests in 13 files.
+#
+# Revision 1.12  2002/12/13 16:26:03  abigail
+# Nothing really, just generating a new version.
+# Bloody CPAN/PAUSE doesn't think 1.11 is larger than 1.7.
+#
+# Revision 1.11  2002/09/09 19:29:01  abigail
+# Brazilian Portuguese added (Flavio S. Glock)
+#
+# Revision 1.10  2002/08/20 14:40:26  abigail
+# Documented new language (Swedish).
+# Fixed email address.
+#
+# Revision 1.9  2002/08/20 14:34:52  abigail
+# Fixed the German:
+#    + capitalized the numbers
+#    + fixed the gender of the numbers.
+# (Torsten Hofmann and Andre Bonhote)
+#
+# Added support for Swedish (cpan #718)
+#
+# Revision 1.8  2002/08/20 13:58:08  abigail
+# Moved from RCS to CVS.
+#
 # Revision 1.7  2002/05/15 11:37:39  abigail
 # Fixed regex extracting version number from RCS Revision line.
 # (Tim Heaney)
@@ -41,7 +69,7 @@ use warnings qw /all/;
 
 use vars qw /$VERSION/;
 
-($VERSION)  = q $Revision: 1.7 $ =~ /([\d.]+)/;
+($VERSION)  = q $Revision: 2.100 $ =~ /([\d.]+)/;
 
 my %languages = (
     'en'      => {numbers => [qw /one two three four five six seven
@@ -49,16 +77,26 @@ my %languages = (
                   format  => "The big hand is on the %s " .
                              "and the little hand is on the %s"},
 
-    'de'      => {numbers => [qw /eins zwei drie vier fnf sechs sieben
-                                       acht neun zehn elf zwlf/],
-                  format  => "Der grosse Zeiger ist auf die %s " .
-                             "und der kleine Zeiger ist auf die %s"},
+    'br'      => {numbers => [qw /um dois trs quatro cinco seis
+                                     sete oito nove dez onze doze/],
+                  format  => "O ponteiro grande est no %s " .
+                             "e o ponteiro pequeno est no %s"},
+
+    'de'      => {numbers => [qw /Eins Zwei Drie Vier Fnf Sechs Sieben
+                                       Acht Neun Zehn Elf Zwlf/],
+                  format  => "Der grosse Zeiger ist auf der %s " .
+                             "und der kleine Zeiger ist auf der %s"},
 
     'du'      => {numbers => [qw /een twee drie vier vijf zes zeven
                                       acht negen tien elf twaalf/],
                   format  => "De grote wijzer is op de %s " .
                              "en de kleine wijzer is op de %s"},
 
+    'es'      => {numbers => [qw /uno dos tres cuatro cinco seis siete
+                                      ocho nueve diez once doce/],
+                  format  => "La manecilla grande est sobre el %s " .
+                             "y la manecilla pequea est sobre el %s"},
+
     'fr'      => {numbers => [qw /un deux trois quatre cinq six sept
                                      huit neuf dix onze douze/],
                   format  => "La grande aiguille est sur le %s " .
@@ -76,14 +114,19 @@ my %languages = (
                   format  => "Den store viseren er p %s " .
                              "og den lille viseren er p %s"},
 
+    'se'      => {numbers => [qw /ett tv tre fyra fem sex sju
+                                      tta nio tio elva tolv/],
+                  format  => "Den stora visaren r p %s " .
+                             "och den lilla visaren r p %s"},
+
     'swedish chef'
               => {numbers => [qw /one tvu three ffuoor ffeefe six
-                                  sefen eight nine ten elefen tvelfe/],
+                                      sefen eight nine ten elefen tvelfe/],
                   format  => "Zee beeg hund is un zee %s und zee little " .
                              "hund is un zee %s. Bork, bork, bork!"},
 
     'warez'   => {numbers => [qw {()nE TW0 7HR3e f0uR f|ve 5ix 
-                                  ZE\/3n E|6hT n1nE TeN 3L3v3gn 7wELv3}],
+                                       ZE\/3n E|6hT n1nE TeN 3L3v3gn 7wELv3}],
                   format  => 'T|-|3 bIG h4|\||) Yz 0n thE %s ' .
                              'and 7|-|3 lIttlE |-|aND |S 0|\| Th3 %s'},
 
@@ -145,7 +188,6 @@ sub babytime {
     sprintf $format => @numbers [$minutes, $hours];
 }
 
-
 1;
 
 __END__
@@ -181,12 +223,23 @@ options can be passed:
 =item language LANG
 
 The language the time should be told in. The following languages are
-currently supported: C<en> (for English), C<de> (for German), C<du>
-(for Dutch), C<fr> (for French), C<it> (for Italian), C<no> (for
-Norwegian), C<swedish chef> (for Swedish Chef like time) and C<warez>
-(for l44+ babies).  If no language argument is given, English is used.
+currently supported:
 
-Note that German and Norwegian use accented letters. The returned 
+  en             English (this is the default)
+  br             Brazilian Portuguese.
+  de             German.
+  du             Dutch.
+  es             Spanish.
+  fr             French.
+  it             Italian.
+  no             Norwegian.
+  se             Swedish.
+  swedish chef   Swedish Chef (from the Muppets).
+  warez          l44+.
+
+If no language argument is given, English is used.
+
+Note that some languages use accented letters. The returned 
 sentences are correct for an ISO 8859-1 platform.
 
 =item format STRING
@@ -229,11 +282,39 @@ Support for more languages.
 
 =head1 AUTHOR
 
-Abigail, I<abigail@foad.org>.
+Abigail, I<acme-time-baby@abigail.nl>.
 
 =head1 HISTORY
 
     $Log: Baby.pm,v $
+    Revision 2.100  2003/02/13 13:01:34  abigail
+    - Upped version to 2.100, to make really sure CPAN updates older
+      versions of the module.
+    - Added Spanish. (Nick Tonkin)
+    - 17295 tests in 13 files.
+
+    Revision 1.12  2002/12/13 16:26:03  abigail
+    Nothing really, just generating a new version.
+    Bloody CPAN/PAUSE doesn't think 1.11 is larger than 1.7.
+
+    Revision 1.11  2002/09/09 19:29:01  abigail
+    Brazilian Portuguese added (Flavio S. Glock)
+
+    Revision 1.10  2002/08/20 14:40:26  abigail
+    Documented new language (Swedish).
+    Fixed email address.
+
+    Revision 1.9  2002/08/20 14:34:52  abigail
+    Fixed the German:
+       + capitalized the numbers
+       + fixed the gender of the numbers.
+    (Torsten Hofmann and Andre Bonhote)
+
+    Added support for Swedish (cpan #718)
+
+    Revision 1.8  2002/08/20 13:58:08  abigail
+    Moved from RCS to CVS.
+
     Revision 1.7  2002/05/15 11:37:39  abigail
     Fixed regex extracting version number from RCS Revision line.
     (Tim Heaney)
